@@ -14,14 +14,13 @@ namespace BBSLIST
     // メインビュー
     class BBSListViewMain : public BBSListViewBase
     {
-        bool m_load_etc;
-
       public:
         BBSListViewMain( const std::string& url, const std::string& arg1 = std::string() , const std::string& arg2 = std::string() );
         virtual ~BBSListViewMain();
 
         virtual void show_view();
         virtual void update_view();
+        virtual void delete_view();
 
       protected:
 
@@ -29,6 +28,10 @@ namespace BBSLIST
         virtual void save_xml( bool backup );
 
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
+
+      private:
+
+        virtual void delete_view_impl();
     };
 };
 
