@@ -6,8 +6,12 @@
 #define _CONTROLLABEL_H
 
 #include "controlid.h"
+#include "global.h"
 
-#define MAX_CONTROL_LABEL 64
+enum
+{
+    MAX_CONTROL_LABEL = 64
+};
 
 namespace CONTROL
 {
@@ -26,8 +30,11 @@ namespace CONTROL
         { "TabRight", "右のタブに移動" },
         { "TabLeft", "左のタブに移動" },
 
-        { "PreBookMark", "前のプックマークヘ移動" },
-        { "NextBookMark", "次のプックマークヘ移動" },
+        { "PreBookMark", "前のしおりヘ移動" },
+        { "NextBookMark", "次のしおりヘ移動" },
+
+        { "PrevView", ITEM_NAME_PREVVIEW },
+        { "NextView", ITEM_NAME_NEXTVIEW },
 
         { "ToggleArticle", "スレ一覧とスレビュー切替" },
 
@@ -44,26 +51,29 @@ namespace CONTROL
 
         { "Back", "戻る" },
 
-        { "Quit", "閉じる" },
-        { "Save", "保存" },
-        { "Delete", "削除" },
-        { "Reload", "再読み込み" },
-        { "StopLoading", "読み込み中止" },
+        { "Quit", ITEM_NAME_QUIT },
+        { "Save", "名前を付けて保存..." },
+        { "Delete", ITEM_NAME_DELETE },
+        { "Reload", ITEM_NAME_RELOAD },
+        { "StopLoading", ITEM_NAME_STOPLOADING },
         { "Copy", "コピー" },
-        { "AppendFavorite", "お気に入りに追加" },
-        { "Property", "プロパティ" },
+        { "SelectAll", "全て選択" },
+        { "AppendFavorite", ITEM_NAME_FAVORITE },
+        { "Property", "プロパティ..." },
+        { "Lock", ITEM_NAME_LOCK },
 
-        { "Search", "検索" },
+        { "Search", ITEM_NAME_SEARCH },
         { "CloseSearchBar", "検索バーを閉じる" },
         { "HiLightOff", "ハイライト解除" },
         { "SearchInvert", "前方検索" },
-        { "SearchNext", "次検索" },
-        { "SearchPrev", "前検索" },
+        { "SearchNext", ITEM_NAME_SEARCH_NEXT },
+        { "SearchPrev", ITEM_NAME_SEARCH_PREV },
         { "DrawOutAnd", "AND 抽出" },
         { "DrawOutOr", "OR 抽出" },
 
         { "ClickButton", "クリック" },
         { "DblClickButton", "ダブルクリック" },
+        { "TrpClickButton", "トリプルクリック" },
         { "CloseTabButton", "タブを閉じる" },
         { "ReloadTabButton", "タブを再読み込み" },
         { "AutoScrollButton", "オートスクロール" },
@@ -72,12 +82,6 @@ namespace CONTROL
         { "DragStartButton", "ドラッグ開始" },
         { "TreeRowSelectionButton", "行範囲選択" },
 
-        
-        { "ScrollUp", "" }, // 上スクロール
-        { "ScrollDown", "" },// 下スクロール
-        { "ScrollLeft", "" }, // 左スクロール
-        { "ScrollRight", "" },// 右スクロール
-
         { "", "" },
 
         // BBSLIST
@@ -90,6 +94,9 @@ namespace CONTROL
         { "OpenBoardButton", "板を開く" },
         { "OpenBoardTabButton", "タブで板を開く" },
 
+        { "CheckUpdateRoot", "更新チェック" },
+        { "CheckUpdateOpenRoot", "更新されたスレをタブで開く" },
+
         { "", "" },
 
         // BOARD
@@ -98,9 +105,12 @@ namespace CONTROL
 
         { "OpenArticle", "スレを開く" },
         { "OpenArticleTab", "タブでスレを開く" },
-        { "NewArticle", "新スレ作成" },
+        { "NewArticle", ITEM_NAME_NEWARTICLE },
         { "SearchCache", "ログ検索" },
 
+        { "ScrollLeftBoard", "" }, // 左スクロール
+        { "ScrollRightBoard", "" },// 右スクロール
+
         { "OpenArticleButton", "スレを開く" },
         { "OpenArticleTabButton", "タブでスレを開く" },
 
@@ -116,9 +126,14 @@ namespace CONTROL
         { "DownMid", "中速下移動" },
         { "DownFast", "高速下移動" },
 
+        { "PrevRes", "前のレスへ移動" },
+        { "NextRes", "次のレスへ移動" },
+
         { "GotoNew", "新着へ移動" },
-        { "OpenParentBoard", "板を開く" },
-        { "WriteMessage", "書き込み" },
+        { "OpenParentBoard", ITEM_NAME_OPENBOARD },
+        { "WriteMessage", ITEM_NAME_WRITEMSG },
+
+        { "LiveStartStop", ITEM_NAME_LIVE },
 
         { "PopupWarpButton", "クリックで多重ポップアップモードに移行" },
         { "ReferResButton", "参照レスポップアップ表示" },
@@ -141,24 +156,44 @@ namespace CONTROL
 
         { "", "" },
 
-        // IMAGE
+        // IMAGE ICON
 
         { "", "" },
 
         { "CancelMosaic", "モザイク解除" },
-        { "ZoomFitImage", "画面に画像サイズを会わせる" },
+        { "ZoomFitImage", "画面に画像サイズを合わせる" },
         { "ZoomInImage", "ズームイン" },
         { "ZoomOutImage", "ズームアウト" },
         { "OrgSizeImage", "元の画像サイズ" },
 
+        { "ScrollUpImage", "" }, // 上スクロール
+        { "ScrollDownImage", "" },// 下スクロール
+        { "ScrollLeftImage", "" }, // 左スクロール
+        { "ScrollRightImage", "" },// 右スクロール
+
+        { "CloseImageTabButton", "タブを閉じる" },
+
+        { "", "" },
+
+        // IMAGE VIEW
+
+        { "", "" },
+
+        { "CloseImageButton", "画像を閉じる" },
+        { "ScrollImageButton", "画像スクロール" },
+        { "CancelMosaicButton", "モザイク解除" },
+
         { "", "" },
 
         // MESSAGE
 
         { "", "" },
 
-        { "CancelWrite", "書き込みビューを閉じる" },
-        { "ExecWrite", "書き込み実行" },
+        { "CancelWrite", ITEM_NAME_QUIT },
+        { "ExecWrite", ITEM_NAME_WRITEMSG },
+        { "InsertText", ITEM_NAME_INSERTTEXT  },
+        { "LockMessage", ITEM_NAME_LOCK_MESSAGE },
+        { "Preview", ITEM_NAME_PREVIEW },
 
         { "FocusWrite", "書き込みボタンにフォーカスを移す" },
 
@@ -178,7 +213,7 @@ namespace CONTROL
 
         { "DeleteEdit", "一文字削除" },
         { "BackspEdit", "バックスペース" },
-        { "UndoEdit", "元に戻す(Undo)" },
+        { "UndoEdit", ITEM_NAME_UNDO },
 
         { "InputAA", "アスキーアート入力" },
 
