@@ -20,6 +20,7 @@
 #include "session.h"
 
 #include <sstream>
+#include <cstring>
 
 #ifndef MAX
 #define MAX( a, b ) ( a > b ? a : b )
@@ -33,6 +34,9 @@
 
 enum
 {
+    MAX_WIDTH_EMB = 100, // 埋め込み画像の最大横幅(ピクセル)
+    MAX_HEIGHT_EMB = 100, // 埋め込み画像の最大横幅(ピクセル)
+
     MAX_REDIRECT = 5  // 最大リダイレクト回数
 };
 
@@ -105,6 +109,8 @@ void Img::clear()
     m_type = T_UNKNOWN;
     m_width = 0;
     m_height = 0;
+    m_width_emb = 0;
+    m_height_emb = 0;
     m_abone = false;
 }
 
@@ -344,6 +350,7 @@ void Img::receive_data( const char* data, size_t size )
             stop_load();
 
 #ifdef _DEBUG
+            std::cout << "no image : size = " << size << std::endl;
             std::cout << data << std::endl;
 #endif
         }
@@ -370,7 +377,9 @@ void Img::receive_finish()
 {
 #ifdef _DEBUG
     std::cout << "Img::receive_finish code = " << get_code() << std::endl
+              << "strcode = " << get_str_code() << std::endl
               << "total byte = " << total_length() << std::endl
+              << "contenttype = " << get_contenttype() << std::endl
               << "cookies : " << std::endl;
 
     if( cookies().size() ){
@@ -395,6 +404,10 @@ void Img::receive_finish()
         if( url_tmp.find( "404" ) != std::string::npos && url_tmp.find( ".htm" ) != std::string::npos ) m_type = T_NOT_FOUND;
 
         else if( ! location().empty() && m_count_redirect < MAX_REDIRECT ){
+
+#ifdef _DEBUG
+            std::cout << "exec redirect\n";
+#endif
             ++m_count_redirect;
             m_url_alt = location();
             download_img( m_refurl );
@@ -411,6 +424,7 @@ void Img::receive_finish()
 
         MISC::get_img_size( get_cache_path(), m_width, m_height );
         if( ! m_width || ! m_height ) m_type = T_NOSIZE;
+        else set_embedded_size();
     }
 
 
@@ -419,7 +433,7 @@ void Img::receive_finish()
 
     if( m_type == T_NOIMG ){
         set_code( HTTP_ERR );
-        set_str_code( "画像ファイルではありません" );
+        set_str_code( "画像ファイルではありません (" + get_contenttype() + ")" );
         set_current_length( 0 );
     }
 
@@ -502,6 +516,24 @@ void Img::receive_finish()
 }
 
 
+// 埋め込み画像のサイズを計算
+void Img::set_embedded_size()
+{
+    if( ! m_width || ! m_height ) return;
+
+    // 縮小比率を計算してサイズ取得
+    double scale;
+    double scale_w = ( double ) MAX_WIDTH_EMB / m_width;
+    double scale_h = ( double ) MAX_HEIGHT_EMB / m_height;
+    scale = MIN( scale_w, scale_h );
+
+    m_width_emb = (int)( m_width * scale );
+    m_height_emb = (int)( m_height * scale );
+
+#ifdef _DEBUG
+    std::cout << "Img::set_embedded_size w = " << m_width_emb << " h = " << m_height_emb << std::endl;
+#endif
+}
 
 
 //
@@ -612,6 +644,7 @@ void Img::read_info()
             if( total_length() ) save_info();
         }
         set_current_length( total_length() );
+        set_embedded_size();
     }
 
 #ifdef _DEBUG
