@@ -16,25 +16,22 @@ namespace Gtk
 
 namespace DBIMG
 {
-    // 画像タイプ
-    enum{
-        T_NOIMG = 0,
-        T_JPG,
-        T_PNG,
-        T_GIF,
-        T_LARGE,
-        T_OPENFAILED,
-        T_WRITEFAILED,
-        T_UNKNOWN
-    };
-
     class Img : public SKELETON::Loadable
     {
         std::string m_url;
+        std::string m_url_alt; // リダイレクトなどで使用するアドレス
+        int m_count_redirect; // リダイレクト回数
 
         int m_type; // 画像タイプ
+
+        // 幅、高さ
         int m_width;
         int m_height;
+
+        // 埋め込み画像の幅、高さ
+        int m_width_emb;
+        int m_height_emb;
+
         bool m_mosaic; // モザイクかける
         bool m_zoom_to_fit; // windowにサイズをあわせる
         int m_size; // 画像の大きさ(パーセントで)
@@ -53,12 +50,18 @@ namespace DBIMG
         void clear();
 
         const std::string& url() const { return m_url; }
-        std::string get_cache_path();
+        const std::string get_cache_path();
 
         const int get_type() const { return m_type; }
+        void set_type( const int type ){ m_type = type; }
 
-        const int get_width();
-        const int get_height();
+        // 高さ、幅
+        const int get_width() const { return m_width; }
+        const int get_height() const { return m_height; }
+
+        // スレ埋め込み画像の高さ、幅
+        const int get_width_emb() const { return m_width_emb; }
+        const int get_height_emb() const { return m_height_emb; }
 
         const bool is_cached();
 
@@ -68,6 +71,8 @@ namespace DBIMG
         const bool get_mosaic() const { return m_mosaic; }
         void set_mosaic( bool mosaic );
 
+        void show_large_img();
+
         const bool is_zoom_to_fit() const { return m_zoom_to_fit; }
         void set_zoom_to_fit( bool fit ) { m_zoom_to_fit = fit; }
 
@@ -76,19 +81,25 @@ namespace DBIMG
         const int get_size() const { return m_size; }
         void set_size( int size ) { m_size = size; }
 
-        const bool is_protected() const { return m_protect; }
         const std::string& get_refurl() const { return m_refurl; }
 
+        const bool is_protected() const { return m_protect; }
         void set_protect( bool protect );
 
-        void download_img( const std::string& refurl );
-        bool save( Gtk::Window* parent, const std::string& path_to );
+        // 拡張子が偽装されているか
+        const bool is_fake(); 
+
+        void download_img( const std::string refurl );
+        const bool save( Gtk::Window* parent, const std::string& path_to );
         
       private:
 
         virtual void receive_data( const char* data, size_t size );
         virtual void receive_finish();
 
+        // 埋め込み画像のサイズを計算
+        void set_embedded_size();
+
         void read_info();
         void save_info();
     };
