@@ -18,6 +18,7 @@
 #include "global.h"
 
 #include <sstream>
+#include <cstring>
 
 using namespace DBTREE;
 
@@ -53,10 +54,16 @@ Board2chCompati::Board2chCompati( const std::string& root, const std::string& pa
 
 Board2chCompati::~Board2chCompati()
 {
-    if( m_settingloader ) delete m_settingloader;
+    if( m_settingloader ){
+        m_settingloader->terminate_load();
+        delete m_settingloader;
+    }
     m_settingloader = NULL;
 
-    if( m_ruleloader ) delete m_ruleloader;
+    if( m_ruleloader ){
+        m_ruleloader->terminate_load();
+        delete m_ruleloader;
+    }
     m_ruleloader = NULL;
 }
 
@@ -176,7 +183,7 @@ const std::string Board2chCompati::create_newarticle_message( const std::string&
     ss_post.clear();
     ss_post << "bbs="      << get_id()
             << "&subject=" << MISC::charset_url_encode( subject, get_charset() )
-            << "&time="    << time_modified()
+            << "&time="    << get_time_modified()
             << "&submit="  << MISC::charset_url_encode( "新規スレッド作成", get_charset() )
             << "&FROM="    << MISC::charset_url_encode( name, get_charset() )
             << "&mail="    << MISC::charset_url_encode( mail, get_charset() )
@@ -227,7 +234,12 @@ ArticleBase* Board2chCompati::append_article( const std::string& id, bool cached
     if( empty() ) return get_article_null();
 
     ArticleBase* article = new DBTREE::Article2chCompati( url_datbase(), id, cached );
-    if( article ) get_list_article().push_back( article );
+    if( article ){
+        get_list_article().push_back( article );
+
+        // 最大レス数セット
+        article->set_number_max( get_number_max_res() );
+    }
     else return get_article_null();
     
     return article;
