@@ -108,7 +108,7 @@ void NodeTreeJBBS::create_loaderdata( JDLIB::LOADERDATA& data )
     data.size_buf = CONFIG::get_loader_bufsize();
     data.timeout = CONFIG::get_loader_timeout();
 
-    if( ! date_modified().empty() ) data.modified = date_modified();
+    if( ! get_date_modified().empty() ) data.modified = get_date_modified();
 
 #ifdef _DEBUG    
     std::cout << "NodeTreeJBBS::create_loader : " << data.url << std::endl;
@@ -120,8 +120,11 @@ void NodeTreeJBBS::create_loaderdata( JDLIB::LOADERDATA& data )
 // raw データを dat 形式に変換
 //
 
-#define MIN_SECTION 5
-#define MAX_SECTION 8
+enum
+{
+    MIN_SECTION = 5,
+    MAX_SECTION = 8
+};
 
 const char* NodeTreeJBBS::raw2dat( char* rawlines, int& byte )
 {
