@@ -11,6 +11,8 @@
 #include "dbtree/spchar_decoder.h"
 
 #include <sstream>
+#include <cstring>
+#include <cstdlib>
 
 
 //
@@ -445,6 +447,28 @@ std::list< std::string > MISC::replace_str_list( std::list< std::string >& list_
 }
 
 
+// str_in に含まれる改行文字を replace に置き換え
+std::string MISC::replace_newlines_to_str( const std::string& str_in, const std::string& replace )
+{
+    if( str_in.empty() || replace.empty() ) return str_in;
+
+    std::string str_out;
+
+    size_t pos = 0, found = 0;
+    while( ( found = str_in.find_first_of( "\r\n", pos ) ) != std::string::npos )
+    {
+        str_out.append( str_in.substr( pos, ( found - pos ) ) + replace );
+
+        pos = found + 1;
+
+        if( str_in[ found ] == '\r' && str_in[ found + 1 ] == '\n' ) ++pos;
+    }
+
+    str_out.append( str_in.substr( pos ) );
+
+    return str_out;
+}
+
 
 // " を \" に置き換え
 std::string MISC::replace_quot( const std::string& str )
@@ -476,6 +500,15 @@ int MISC::count_str( const std::string& str, const std::string& str2  )
 }
 
 
+// str 中に含まれている chr の 数を返す
+const int MISC::count_chr( const std::string& str, const char chr )
+{
+    int count = 0;
+    const int size = str.size();
+    for( int i = 0; i < size; ++i ) if( str.c_str()[i] == chr ) ++count;
+    return count;
+}
+
 
 //
 // 文字列(utf-8も) -> 整数変換
@@ -574,6 +607,41 @@ std::string MISC::intlisttostr( std::list< int >& list_num )
 
 
 
+//
+// 16進数表記文字をバイナリに変換する( "E38182" -> 0xE38182 )
+//
+// 戻り値: 変換に成功した chr_in のバイト数
+//
+size_t MISC::chrtobin( const char* chr_in, char* chr_out )
+{
+    if( ! chr_in ) return 0;
+
+    const size_t chr_in_length = strlen( chr_in );
+
+    size_t a, b;
+    for( a = 0, b = a; a < chr_in_length; ++a )
+    {
+        unsigned char chr = chr_in[a];
+
+        chr_out[b] <<= 4;
+
+        // 0(0x30)〜9(0x39)
+        if( ( chr - 0x30 ) < 0x0A ) chr_out[b] |= chr - 0x30;
+        // A(0x41)〜F(0x46)
+        else if( ( chr - 0x41 ) < 0x06 ) chr_out[b] |= chr - 0x37;
+        // a(0x61)〜f(0x66)
+        else if( ( chr - 0x61 ) < 0x06 ) chr_out[b] |= chr - 0x57;
+        // その他
+        else break;
+
+        if( a % 2 != 0 ) ++b;
+    }
+
+    return a;
+}
+
+
+
 // strが半角でmaxsize文字を超えたらカットして後ろに...を付ける
 std::string MISC::cut_str( const std::string& str, unsigned int maxsize )
 {
@@ -624,7 +692,7 @@ std::string MISC::html_escape( const std::string& str, const bool include_url )
 
             // URLスキームが含まれているか判別
             int len = 0;
-            if( ! is_url ) scheme = is_url_scheme( str.c_str() + pos, len );
+            if( ! is_url ) scheme = is_url_scheme( str.c_str() + pos, &len );
 
             // URLスキームが含まれていた場合は文字数分進めてループに戻る
             if( len > 0 )
@@ -707,10 +775,10 @@ std::string MISC::html_unescape( const std::string& str )
 // 戻り値 : スキームタイプ
 // len    : "http://"等の文字数
 //
-int MISC::is_url_scheme( const char* str_in, int& len )
+int MISC::is_url_scheme( const char* str_in, int* length )
 {
     int scheme = SCHEME_NONE;
-    len = 0;
+    int len = 0;
 
     // 候補になり得ない場合は以降の処理はしない
     if( *str_in != 'h' && *str_in != 'f' && *str_in != 't' ) return scheme;
@@ -746,7 +814,11 @@ int MISC::is_url_scheme( const char* str_in, int& len )
 
     // 各スキーム後に続く共通の"://"
     if( *( str_in + len ) == ':' && *( str_in + len + 1 ) == '/'
-        && *( str_in + len + 2 ) == '/' ) len += 3;
+        && *( str_in + len + 2 ) == '/' )
+    {
+        len += 3;
+        if( length ) *length = len;
+    }
     else scheme = SCHEME_NONE;
 
     return scheme;
@@ -805,6 +877,52 @@ bool MISC::is_url_char( const char* str_in, const bool loose_url )
 }
 
 
+
+//
+// URLデコード
+//
+std::string MISC::url_decode( const std::string& url )
+{
+    if( url.empty() ) return std::string();
+
+    const size_t url_length = url.length();
+
+    char decoded[ url_length + 1 ];
+    memset( decoded, 0, sizeof( decoded ) );
+
+    unsigned int a, b;
+    for( a = 0, b = a; a < url_length; ++a, ++b )
+    {
+        if( url[a] == '%' )
+        {
+            char src[3];
+            memset( src, 0, 3 );
+            memcpy( src, &url[ a + 1 ], 2 );
+
+            char tmp[3];
+            memset( tmp, 0, 3 );
+
+            if( chrtobin( src, tmp ) == 2 )
+            {
+                decoded[b] = *tmp;
+                a += 2;
+            }
+            else decoded[b] = url[a];
+        }
+        else if( url[a] == '+' )
+        {
+            decoded[b] = ' ';
+        }
+        else
+        {
+            decoded[b] = url[a];
+        }
+    }
+
+    return std::string( decoded );
+}
+
+
 //
 // url エンコード
 //
@@ -965,7 +1083,7 @@ int MISC::utf8toucs2( const char* utfstr, int& byte )
     int ucs2 = 0;
     byte = 0;
 
-    if( utfstr[ 0 ] == '\0' ) return ucs2;
+    if( utfstr[ 0 ] == '\0' ) return '\0';
     
     if( ( ( unsigned char ) utfstr[ 0 ] & 0x80 ) == 0 ){ // ascii
         byte = 1;
@@ -1039,6 +1157,18 @@ int MISC::ucs2toutf8( int ucs2, char* utfstr )
 }
 
 
+//
+// ucs2 の種類
+//
+int MISC::get_ucs2mode( const int ucs2 )
+{
+    if( ucs2 >= 0x0000 && ucs2 <= 0x007f ) return UCS2MODE_BASIC_LATIN;
+    if( ucs2 >= 0x3040 && ucs2 <= 0x309f ) return UCS2MODE_HIRA;
+    if( ucs2 >= 0x30a0 && ucs2 <= 0x30ff ) return UCS2MODE_KATA;
+
+    return UCS2MODE_OTHER;
+}
+
 
 //
 // str を大文字化
@@ -1167,3 +1297,18 @@ std::string MISC::get_svn_revision( const char* rev )
     return svn_revision;
 }
 
+
+//
+// 文字数を限定して環境変数の値を返す
+//
+std::string MISC::getenv_limited( const char *name, const size_t size )
+{
+    if( ! name || ! getenv( name ) ) return std::string();
+
+    char env[ size + 1 ];
+    env[ size ] = '\0';
+
+    strncpy( env, getenv( name ), size );
+
+    return std::string( env );
+}
