@@ -1,20 +1,28 @@
 // ライセンス: GPL2
 
 //#define _DEBUG
+//#define _DEBUG_MEM_PROFILE
 #include "jddebug.h"
 
 #include "config/globalconf.h"
 
 #include "winmain.h"
 #include "cache.h"
+#include "jdversion.h"
+#include "iomonitor.h"
 
 #include "jdlib/miscmsg.h"
 #include "jdlib/miscutil.h"
+#include "jdlib/ssl.h"
 
 #include <signal.h>
 #include <string>
-#include <fstream>
 #include <sys/time.h>
+#include <errno.h>
+#include <cstring>
+#include <sstream>
+#include <iostream>
+#include <getopt.h>
 
 #ifdef USE_GNOMEUI
 #include <gnome.h>
@@ -32,40 +40,14 @@ struct XSMPDATA
 };
 #endif
 
+enum
+{
+    MAX_SAFE_ARGC = 4,   // 引数の数の制限値
+    MAX_SAFE_ARGV = 1024 // 各引数の文字列の制限値
+};
+
 WinMain* Win_Main = NULL;
 
-// ロック
-// 既にロックされていたら false
-bool lock_jd()
-{
-    std::string path = CACHE::path_lock();
-
-    if( CACHE::is_file_exists( path ) == CACHE::EXIST_FILE ) return false;
-
-    std::ofstream ofs;
-    ofs.open( path.c_str() );
-    if( !ofs.is_open() ){
-        MISC::ERRMSG( "can't open " + path );
-    }
-    else{
-
-        ofs << "lock";
-        ofs.close();
-    }
-
-    return true;
-}
-
-
-// ロック解除
-void unlock_jd()
-{
-    std::string path = CACHE::path_lock();
-
-    if( CACHE::is_file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
-}
-
-
 
 // バックアップ復元
 void restore_bkup()
@@ -81,17 +63,17 @@ void restore_bkup()
     std::string path_main_old = path_main + "." + MISC::itostr( tv.tv_sec );
     std::string path_favor_old = path_favor + "." + MISC::itostr( tv.tv_sec );
 
-    bool bkup_main = ( CACHE::is_file_exists( path_main_bkup ) == CACHE::EXIST_FILE );
-    bool bkup_favor = ( CACHE::is_file_exists( path_favor_bkup ) == CACHE::EXIST_FILE );
+    bool bkup_main = ( CACHE::file_exists( path_main_bkup ) == CACHE::EXIST_FILE );
+    bool bkup_favor = ( CACHE::file_exists( path_favor_bkup ) == CACHE::EXIST_FILE );
 
     if( bkup_main || bkup_favor ){
 
         Gtk::MessageDialog* mdiag
-        = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nキャンセルを押すとバックアップファイルを削除します。",
-                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+        = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nいいえを押すとバックアップファイルを削除します。",
+                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret == Gtk::RESPONSE_OK ){
+        if( ret == Gtk::RESPONSE_YES ){
 
             if( bkup_main ){
                 rename( path_main.c_str(), path_main_old.c_str() );
@@ -131,7 +113,6 @@ void sig_handler( int sig )
         std::cout << "sig_handler sig = " << sig << std::endl;
 #endif
         if( Win_Main ) Win_Main->shutdown();
-        unlock_jd();
     }
 
     exit(0);
@@ -154,7 +135,6 @@ static int save_yourself_gnome( GnomeClient *client,
 {
 
     if( Win_Main ) Win_Main->save_session();
-    unlock_jd();
 
     return TRUE;
 }
@@ -179,7 +159,6 @@ void xsmp_session_save_yourself( SmcConn smc_connect,
         std::cout << "session_save_yourself\n";
 #endif
         if( Win_Main ) Win_Main->save_session();
-        unlock_jd();
     }
 
     SmcSaveYourselfDone( smc_connect, TRUE ) ;
@@ -307,8 +286,104 @@ void xsmp_session_end( XSMPDATA* xsmpdata )
 
 ////////////////////////////////////////////////////////////
 
+void usage( const int status )
+{
+    // -h, --help で表示するメッセージ
+    std::stringstream help_message;
+    help_message <<
+    "Usage: jd [option] [<url>]\n"
+    "\n"
+    "-h, --help\n"
+    "        Display this information\n"
+    //"-t <url>, --tab=<url>\n"
+    //"        URL open of BBS etc by Tab\n"
+    "-m, --multi\n"
+    "        Does not terminate even if it is a subprocess\n"
+    "-V, --version\n"
+    "        Display version of this program\n";
+
+    std::cout << help_message.str() << std::endl;
+
+    exit( status );
+}
+
+
 int main( int argc, char **argv )
 {
+    /*--- 引数処理 --------------------------------------------------*/
+
+    // 引数の数を制限
+    if( argc > MAX_SAFE_ARGC )
+    {
+        MISC::ERRMSG( "main(): Too many arguments." );
+        exit( EXIT_FAILURE );
+    }
+
+    // 各引数の文字数を制限
+    int i;
+    for( i = 0; i < argc; ++i )
+    {
+        if( strlen( argv[ i ] ) > MAX_SAFE_ARGV )
+        {
+            MISC::ERRMSG( "main(): Too many the strings in argument." );
+            exit( EXIT_FAILURE );
+        }
+    }
+
+    // "現在のタブ/新規タブ"など引数によって開き方を変えたい場合は、--tab=<url>
+    // など新しいオプションを追加する
+    // --help, --tab=<url>, --multi, --version
+    const struct option options[] =
+    {
+        { "help", 0, 0, 'h' },
+        //{ "tab", 1, 0, 't' },
+        { "multi", 0, 0, 'm' },
+        { "version", 0, 0, 'V' },
+        { 0, 0, 0, 0 }
+    };
+
+    char* url = NULL;
+    bool multi_mode = false;
+
+    // -h, -t <url>, -m, -V
+    int opt = 0;
+    while( ( opt = getopt_long( argc, argv, "ht:mV", options, NULL ) ) != -1 )
+    {
+        switch( opt )
+        {
+            case 'h':
+                usage( EXIT_SUCCESS );
+                break;
+
+            //case 't':
+                //url = optarg;
+                //break;
+
+            case 'm':
+                multi_mode = true;
+                break;
+
+            case 'V':
+                std::cout << "JD " << JDVERSIONSTR << ", " << JDCOPYRIGHT << std::endl;
+                break;
+
+            default:
+                usage( EXIT_FAILURE );
+        }
+    }
+
+    if( ! url )
+    {
+        // 引数がURLのみの場合
+        if( argc > optind )
+        {
+            url = argv[ optind ];
+        }
+        // マルチモードでなく、URLを含まない引数だけの場合は終了
+        else if( optind > 1 && ! multi_mode ) return 0;
+    }
+    /*---------------------------------------------------------------*/
+
     // SIGINT、SIGQUITのハンドラ設定
     struct sigaction sigact;
     sigset_t blockset;
@@ -332,6 +407,21 @@ int main( int argc, char **argv )
         exit( 1 );
     }
 
+#ifdef _DEBUG_MEM_PROFILE
+    g_mem_set_vtable( glib_mem_profiler_table );
+    atexit( g_mem_profile );
+#else
+    GMemVTable vtable;
+    vtable = *glib_mem_profiler_table;
+    vtable.malloc = malloc;
+    vtable.realloc = realloc;
+    vtable.free = free;
+    vtable.calloc = calloc;
+    vtable.try_malloc = malloc;
+    vtable.try_realloc = realloc;
+    g_mem_set_vtable( &vtable );
+#endif
+
     Gtk::Main m( &argc, &argv );
 
     // XSMPによるセッション管理
@@ -360,21 +450,51 @@ int main( int argc, char **argv )
     else MISC::ERRMSG( "failed to connect to gnome session manager" );
 #endif
 
+    JDLIB::init_ssl();
+
     // 全体設定ロード
-    bool init = !( CONFIG::init_config() );
+    bool init = !( CONFIG::load_conf() );
 
-    // 初回起動時にルートを作る
-    if( init ) CACHE::mkdir_root();
+    if( init ){
 
-    // ロック
-    if( ! lock_jd() ){
+        // 設定ファイルが読み込めないときに存在するか確認
+        int exists = CACHE::file_exists( CACHE::path_conf() );
+        if( exists == CACHE::EXIST_FILE || exists == CACHE::EXIST_DIR ){
 
+            std::string msg = "JDの設定ファイル(" + CACHE::path_conf() + ")は存在しますが読み込むことが出来ませんでした。\n\n起動しますか？";
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( msg,
+                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES ) return 0;
+        }
+
+        // 初回起動時にルートを作る
+        CACHE::mkdir_root();
+    }
+
+    /*--- IOMonitor -------------------------------------------------*/
+    CORE::IOMonitor iomonitor;
+
+    // 引数にURLがある
+    if( url )
+    {
+        // FIFOに書き込む
+        iomonitor.send_command( url );
+
+        // マルチモードでなく、メインプロセスでもない場合は終了
+        if( ! multi_mode && ! iomonitor.is_main_process() ) return 0;
+    }
+    // マルチモードでなく、メインプロセスでもない場合は問い合わせる
+    else if( ! multi_mode && ! iomonitor.is_main_process() )
+    {
         Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret != Gtk::RESPONSE_OK ) return 0;
+        if( ret != Gtk::RESPONSE_YES ) return 0;
     }
+    /*---------------------------------------------------------------*/
 
     // バックアップファイル復元
     restore_bkup();
@@ -392,8 +512,7 @@ int main( int argc, char **argv )
     xsmp_session_end( &xsmpdata );
 #endif
 
-    // ロック解除
-    unlock_jd();
+    JDLIB::deinit_ssl();
 
     return 0;
 }
