@@ -42,6 +42,10 @@ namespace SKELETON
         std::vector< Gtk::MenuItem* > m_vec_movemenu_items;
         std::vector< bool > m_vec_movemenu_append;
 
+        // view履歴使用
+        bool m_use_viewhistory;
+        std::string m_last_closed_url;
+
     public:
 
         Admin( const std::string& url );
@@ -106,13 +110,13 @@ namespace SKELETON
 
     protected:
 
+        void set_use_viewhistory( const bool use ){ m_use_viewhistory = use; }
+        const bool get_use_viewhistory() const { return m_use_viewhistory; }
+
         JDWindow* get_jdwin(){ return m_win; }
         void set_jdwin( JDWindow* win ){ m_win = win; }
         void delete_jdwin();
 
-        // 移転などでviewのホスト名を更新
-        void update_host( const std::string& oldhost, const std::string& newhost );
-
         // URLやステータスを更新
         void update_status( View* view, const bool force );
 
@@ -137,11 +141,17 @@ namespace SKELETON
         virtual void exec_command();
 
         // 派生クラス固有のコマンドを実行
-        virtual void command_local( const COMMAND_ARGS& command ){}
+        virtual void command_local( const COMMAND_ARGS& command ) = 0;
+
+        // 起動時に前回の状態を回復
+        virtual void restore( const bool only_locked ) = 0;
+
+        // url から Viewを開くための COMMAND_ARGS を取得する
+        // restore() などで使用する
+        virtual COMMAND_ARGS url_to_openarg( const std::string& url, const bool tab, const bool lock ) = 0; 
 
-        virtual void restore(){} // 起動時に前回の状態を回復
         virtual void open_view( const COMMAND_ARGS& command );
-        virtual void switch_admin(){} // CORE::core_set_command( "switch_*" )　を送る
+        virtual void switch_admin() = 0;  // CORE::core_set_command( "switch_*" )　を送る
         virtual void switch_view( const std::string& url );
         virtual void tab_left();
         virtual void tab_right();
@@ -170,18 +180,16 @@ namespace SKELETON
         virtual void relayout_all();
         virtual void open_window(){}
         virtual void close_window(){}
-        virtual void toggle_toolbar();
-        virtual void update_toolbar();
         virtual void toggle_tab();
         virtual void toggle_icon( const std::string& url );
 
         // オートリロードのモード設定
         virtual bool set_autoreload_mode( const std::string& url, int mode, int sec );
 
-        // D&D
+        // D&D 処理
         // 派生クラス別にD&Dの処理を行う
-        virtual void slot_drag_begin( int page ){}
-        virtual void slot_drag_end(){}
+        virtual void slot_drag_begin( int page ) = 0;
+        virtual void slot_drag_end() = 0;
 
         void open_list( const std::string& str_list );
         virtual COMMAND_ARGS get_open_list_args( const std::string& url ){ return COMMAND_ARGS(); }
@@ -191,6 +199,15 @@ namespace SKELETON
         std::list< View* > get_list_view();
         virtual View* get_current_view();
 
+        // ツールバー
+        virtual void show_toolbar(){}
+        virtual void toggle_toolbar(){}
+        void focus_toolbar_search();
+        void redraw_toolbar();
+        void update_toolbar_button();
+        virtual void open_searchbar(){}
+        virtual void close_searchbar(){}
+
         // タブの更新チェック
         void check_update_all_tabs( const int from_page );
 
@@ -242,6 +259,26 @@ namespace SKELETON
 
         // プロパティ表示
         void show_preference();
+
+        // View履歴戻る / 進む
+        bool back_viewhistory( const std::string& url, const int count );
+        void back_clicked_viewhistory( const int count );
+
+        bool forward_viewhistory( const std::string& url, const int count );
+        void forward_clicked_viewhistory( const int count );
+
+        // View履歴削除
+        void clear_viewhistory();
+
+      private:
+
+        bool back_forward_viewhistory( const std::string& url, const bool back, const int count );
+
+        // 移転などでviewのurlを更新
+        void update_url( const std::string& url_old, const std::string& url_new );
+
+        // urlを含むviewの板名を更新
+        void update_boardname( const std::string& url );
     };
 }
 
